@@ -136,7 +136,15 @@ class MyCache(apt.Cache):
     HoldReInstReq = 3
 
     # init
-    def __init__(self, config, view, quirks, progress=None, lock=True):
+    def __init__(self,
+                 config,
+                 view,
+                 quirks,
+                 progress=None,
+                 lock=True,
+                 from_dist=None,
+                 to_dist=None):
+
         self.to_install = []
         self.to_remove = []
         self.view = view
@@ -145,6 +153,8 @@ class MyCache(apt.Cache):
         self.partialUpgrade = False
         self.config = config
         self.metapkgs = self.config.getlist("Distro", "MetaPkgs")
+        self.from_dist = from_dist
+        self.to_dist = to_dist
         # acquire lock
         self._listsLock = -1
         if lock:
@@ -166,12 +176,6 @@ class MyCache(apt.Cache):
         self.uname = Popen(["uname", "-r"], stdout=PIPE,
                            universal_newlines=True).communicate()[0].strip()
         self._initAptLog()
-        # from hardy on we use recommends by default, so for the
-        # transition to the new dist we need to enable them now
-        if (config.get("Sources", "From") == "hardy" and
-            not "RELEASE_UPGRADE_NO_RECOMMENDS" in os.environ):
-            apt_pkg.config.set("APT::Install-Recommends", "true")
-
         apt_pkg.config.set("APT::AutoRemove::SuggestsImportant", "false")
 
     @property
@@ -617,6 +621,12 @@ class MyCache(apt.Cache):
             # run PreDistUpgradeCache quirks
             self.pre_upgrade_rule()
 
+            # install missing meta-packages (if not in server upgrade mode)
+            self._keepBaseMetaPkgsInstalled(view)
+            if not serverMode:
+                # if this fails, a system error is raised
+                self._installMetaPkgs(view)
+
             # upgrade (and make sure this way that the cache is ok)
             self.upgrade(True)
 
@@ -639,12 +649,6 @@ class MyCache(apt.Cache):
             # and if we have some special rules
             self.post_upgrade_rule()
 
-            # install missing meta-packages (if not in server upgrade mode)
-            self._keepBaseMetaPkgsInstalled(view)
-            if not serverMode:
-                # if this fails, a system error is raised
-                self._installMetaPkgs(view)
-
             # see if it all makes sense, if not this function raises
             self._verifyChanges()
 
@@ -871,6 +875,7 @@ class MyCache(apt.Cache):
         # we never go without ubuntu-base
         for pkg in self.config.getlist("Distro", "BaseMetaPkgs"):
             self[pkg].mark_install()
+            apt.ProblemResolver(self).protect(self[pkg])
 
         # every meta-pkg that is installed currently, will be marked
         # install (that result in a upgrade and removes a mark_delete)
@@ -881,6 +886,7 @@ class MyCache(apt.Cache):
                     self[key].is_upgradable):
                     logging.debug("Marking '%s' for upgrade" % key)
                     self[key].mark_upgrade()
+                    apt.ProblemResolver(self).protect(self[key])
             except SystemError as e:
                 # warn here, but don't fail, its possible that meta-packages
                 # conflict (like ubuntu-desktop vs xubuntu-desktop) LP: #775411
@@ -1034,8 +1040,6 @@ class MyCache(apt.Cache):
         in the returned dict.
         '''
         foreign = dict()
-        from_dist = self.config.get('Sources', 'From')
-        to_dist = self.config.get('Sources', 'To')
 
         for pkg in self:
             if not (pkg.is_installed and pkg.candidate):
@@ -1050,8 +1054,8 @@ class MyCache(apt.Cache):
                     if not (
                         pkg_file.origin == 'Ubuntu' and
                         (
-                            pkg_file.archive.startswith(from_dist) or
-                            pkg_file.archive.startswith(to_dist)
+                            pkg_file.archive.startswith(self.from_dist) or
+                            pkg_file.archive.startswith(self.to_dist)
                         )
                     ):
                         # This is a foreign package
@@ -1110,14 +1114,7 @@ class MyCache(apt.Cache):
         # make sure mounted is sorted by longest path
         mounted.sort(key=len, reverse=True)
         archivedir = apt_pkg.config.find_dir("Dir::Cache::archives")
-        aufs_rw_dir = "/tmp/"
-        if (hasattr(self, "config") and
-            self.config.getWithDefault("Aufs", "Enabled", False)):
-            aufs_rw_dir = self.config.get("Aufs", "RWDir")
-            if not os.path.exists(aufs_rw_dir):
-                os.makedirs(aufs_rw_dir)
-        logging.debug("cache aufs_rw_dir: %s" % aufs_rw_dir)
-        for d in ["/", "/usr", "/var", "/boot", archivedir, aufs_rw_dir, "/home", "/tmp/"]:
+        for d in ["/", "/usr", "/var", "/boot", archivedir, "/home", "/tmp/"]:
             d = os.path.realpath(d)
             fs_id = make_fs_id(d)
             if os.path.exists(d):
@@ -1160,16 +1157,6 @@ class MyCache(apt.Cache):
         # /usr is assumed to get *all* of the install space (incorrect,
         #      but as good as we can do currently + safety buffer
         # /     has a small safety buffer as well
-        required_for_aufs = 0.0
-        if (hasattr(self, "config") and
-            self.config.getWithDefault("Aufs", "Enabled", False)):
-            logging.debug("taking aufs overlay into space calculation")
-            aufs_rw_dir = self.config.get("Aufs", "RWDir")
-            # if we use the aufs rw overlay all the space is consumed
-            # the overlay dir
-            for pkg in self:
-                if pkg.marked_upgrade or pkg.marked_install:
-                    required_for_aufs += pkg.candidate.installed_size
 
         # add old size of the package if we use snapshots
         required_for_snapshots = 0.0
@@ -1190,7 +1177,6 @@ class MyCache(apt.Cache):
                             ("/boot", space_in_boot),
                             ("/tmp", 5*1024*1024),   # /tmp for dkms LP: #427035
                             ("/", 10*1024*1024),     # small safety buffer /
-                            (aufs_rw_dir, required_for_aufs),
                             # if snapshots are in use
                             ("/usr", required_for_snapshots),
                            ]:
