@@ -2,6 +2,7 @@
 #
 #  Copyright (c) 2007 Canonical Ltd
 #  Copyright (c) 2014-2018 Harald Sitter <sitter@kde.org>
+#  Copyright (c) 2024 Simon Quigley <tsimonq2@ubuntu.com>
 #
 #  Author: Jonathan Riddell <jriddell@ubuntu.com>
 #
@@ -20,33 +21,13 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 #  USA
 
-try:
-    # 14.04 has a broken pyqt5, so don't even try to import it and require
-    # pyqt4.
-    # In 14.04 various signals in pyqt5 can not be connected because it thinks
-    # the signal does not exist or has an incompatible signature. Since this
-    # potentially renders the GUI entirely broken and pyqt5 was not actively
-    # used back then it is fair to simply require qt4 on trusty systems.
-    from .utils import get_dist
-    if get_dist() == 'trusty':
-        raise ImportError
+from PyQt6 import uic
+from PyQt6.QtCore import Qt, QLocale, QTranslator, QTimer
+from PyQt6.QtWidgets import QTextEdit, QApplication, QDialog,\
+    QMessageBox, QDialogButtonBox, QTreeWidgetItem, QPushButton, QWidget,\
+    QHBoxLayout, QLabel
+from PyQt6.QtGui import QTextOption, QPixmap, QIcon, QTextCursor
 
-    from PyQt5 import uic
-    from PyQt5.QtCore import Qt, QLocale, QTranslator, PYQT_VERSION, QTimer
-    from PyQt5.QtWidgets import QTextEdit, QApplication, QDialog,\
-        QMessageBox, QDialogButtonBox, QTreeWidgetItem, QPushButton, QWidget,\
-        QHBoxLayout, QLabel
-    from PyQt5.QtGui import QTextOption, QPixmap, QIcon, QTextCursor
-    from PyQt5.QtDBus import QDBusConnection, QDBusInterface, QDBusReply
-except ImportError:
-    from PyQt4 import uic
-    from PyQt4.QtCore import Qt, QLocale, QTranslator, PYQT_VERSION, QTimer
-    from PyQt4.QtGui import QTextEdit, QDialog, QTextOption, QApplication,\
-        QMessageBox, QDialogButtonBox, QTreeWidgetItem, QPixmap, QIcon,\
-        QPushButton, QWidget, QTextCursor, QHBoxLayout, QLabel
-    # If we still throw an exception, bounce back to Main to try another UI.
-
-import atexit
 import sys
 import locale
 import logging
@@ -56,6 +37,7 @@ import traceback
 
 import apt
 import apt_pkg
+import distro_info
 import shlex # for osrelease
 import os
 
@@ -64,6 +46,7 @@ import pty
 from .DistUpgradeApport import run_apport, apport_crash
 
 from .DistUpgradeView import DistUpgradeView, FuzzyTimeToStr, InstallProgress, AcquireProgress
+from .DistUpgradeConfigParser import DistUpgradeConfig
 from .telemetry import get as get_telemetry
 
 import select
@@ -94,14 +77,7 @@ def _find_pixmap(path):
     return None
 
 def _icon(name, fallbacks = []):
-    if type(PYQT_VERSION) == int:
-        return QIcon.fromTheme(name)
-    else:
-        for path in fallbacks:
-            pixmap = _find_pixmap(path)
-            if pixmap:
-                return QIcon(pixmap)
-    return None
+    return QIcon.fromTheme(name)
 
 # QWidget adjustSize when run on a maximized window will make Qt 5.9, earlier,
 # and probably also later, lose its state. Qt will think the window is no longer
@@ -177,7 +153,7 @@ class DumbTerminal(QTextEdit):
         self.setFontFamily("Monospace")
         # FIXME: fixed font size set!!!
         self.setFontPointSize(8)
-        self.setWordWrapMode(QTextOption.NoWrap)
+        self.setWordWrapMode(QTextOption.WrapMode.NoWrap)
         self.setUndoRedoEnabled(False)
         self.setOverwriteMode(True)
         self._block = False
@@ -223,15 +199,15 @@ class DumbTerminal(QTextEdit):
         if not hasattr(self.installProgress, "master_fd"):
             return
         # special handling for backspace
-        if ev.key() == Qt.Key_Backspace:
+        if ev.key() == Qt.Key.Key_Backspace:
             #print("sent backspace")
-            os.write(self.installProgress.master_fd, chr(8))
+            os.write(self.installProgress.master_fd, b'\x08')
             return
         # do nothing for events like "shift"
         if not ev.text():
             return
-        # now sent the key event to the termianl as utf-8
-        os.write(self.installProgress.master_fd, ev.text().toUtf8())
+        # now send the key event to the terminal as utf-8
+        os.write(self.installProgress.master_fd, ev.text().encode('utf-8'))
 
     def onCursorPositionChanged(self):
         """ helper that ensures that the cursor is always at the end """
@@ -243,27 +219,6 @@ class DumbTerminal(QTextEdit):
         self._block = False
 
 
-class KDECdromProgressAdapter(apt.progress.base.CdromProgress):
-    """ Report the cdrom add progress """
-    def __init__(self, parent):
-        self.status = parent.window_main.label_status
-        self.progressbar = parent.window_main.progressbar_cache
-        self.parent = parent
-
-    def update(self, text, step):
-        """ update is called regularly so that the gui can be redrawn """
-        if text:
-          self.status.setText(text)
-        self.progressbar.setValue(step.value/float(self.totalSteps))
-        QApplication.processEvents()
-
-    def ask_cdrom_name(self):
-        return (False, "")
-
-    def change_cdrom(self):
-        return False
-
-
 class KDEOpProgress(apt.progress.base.OpProgress):
   """ methods on the progress bar """
   def __init__(self, progressbar, progressbar_label):
@@ -279,7 +234,7 @@ class KDEOpProgress(apt.progress.base.OpProgress):
       #else:
       #    self.progressbar.pulse()
       #self.progressbar.set_fraction(self.percent/100.0)
-      self.progressbar.setValue(self.percent)
+      self.progressbar.setValue(int(self.percent))
       QApplication.processEvents()
 
   def done(self):
@@ -300,8 +255,8 @@ class KDEAcquireProgressAdapter(AcquireProgress):
 
     def media_change(self, medium, drive):
       msg = _("Please insert '%s' into the drive '%s'") % (medium,drive)
-      change = QMessageBox.question(self.parent.window_main, _("Media Change"), msg, QMessageBox.Ok, QMessageBox.Cancel)
-      if change == QMessageBox.Ok:
+      change = QMessageBox.question(self.parent.window_main, _("Media Change"), msg, QMessageBox.StandardButton.Ok, QMessageBox.StandardButton.Cancel)
+      if change == QMessageBox.StandardButton.Ok:
         return True
       return False
 
@@ -320,7 +275,7 @@ class KDEAcquireProgressAdapter(AcquireProgress):
         # FIXME: move the status_str and progress_str into python-apt
         # (python-apt need i18n first for this)
         AcquireProgress.pulse(self, owner)
-        self.progress.setValue(self.percent)
+        self.progress.setValue(int(self.percent))
         current_item = self.current_items + 1
         if current_item > self.total_items:
             current_item = self.total_items
@@ -402,7 +357,7 @@ class KDEInstallProgressAdapter(InstallProgress):
             dialogue.textview_error.hide()
         # Make sure we have a suitable size depending on whether or not the view is shown
         dialogue.adjustSize()
-        dialogue.exec_()
+        dialogue.exec()
 
     def conffile(self, current, new):
         """ask question in case conffile has been changed by user"""
@@ -433,10 +388,10 @@ class KDEInstallProgressAdapter(InstallProgress):
           self.confDialogue.textview_conffile.setText(diff)
         else:
           self.confDialogue.textview_conffile.setText(_("The 'diff' command was not found"))
-        result = self.confDialogue.exec_()
+        result = self.confDialogue.exec()
         self.time_ui += time.time() - start
         # if replace, send this to the terminal
-        if result == QDialog.Accepted:
+        if result == QDialog.DialogCode.Accepted:
             os.write(self.master_fd, b"y\n")
         else:
             os.write(self.master_fd, b"n\n")
@@ -467,7 +422,7 @@ class KDEInstallProgressAdapter(InstallProgress):
         if self.start_time == 0.0:
           #print("setting start time to %s" % self.start_time)
           self.start_time = time.time()
-        self.progress.setValue(self.percent)
+        self.progress.setValue(int(self.percent))
         self.label_status.setText(utf8(status.strip()))
         # start showing when we gathered some data
         if percent > 1.0:
@@ -544,8 +499,7 @@ class KDEInstallProgressAdapter(InstallProgress):
 class UpgraderMainWindow(QWidget):
 
     def __init__(self):
-        QWidget.__init__(self)
-        #uic.loadUi("window_main.ui", self)
+        super().__init__()
         loadUi("window_main.ui", self)
 
     def setParent(self, parentRef):
@@ -565,13 +519,15 @@ class DistUpgradeViewKDE(DistUpgradeView):
         DistUpgradeView.__init__(self)
 
         get_telemetry().set_updater_type('KDE')
-        # silence the PyQt4 logger
-        logger = logging.getLogger("PyQt4")
+        # silence the PyQt6 logger
+        logger = logging.getLogger("PyQt6")
         logger.setLevel(logging.INFO)
         if not datadir or datadir == '.':
           localedir=os.path.join(os.getcwd(),"mo")
+          self.config = DistUpgradeConfig(os.getcwd())
         else:
           localedir="/usr/share/locale/ubuntu-release-upgrader"
+          self.config = DistUpgradeConfig(datadir)
 
         # FIXME: i18n must be somewhere relative do this dir
         try:
@@ -592,8 +548,8 @@ class DistUpgradeViewKDE(DistUpgradeView):
         os.environ["KDE_FULL_SESSION"] = "TRUE"
         # We also need to indicate version as otherwise KDElibs3 compatibility
         # might kick in such as in QIconLoader.cpp:QString fallbackTheme.
-        os.environ["KDE_SESSION_VERSION"] = "5"
-        # Pretty much all of the above but for Qt5
+        os.environ["KDE_SESSION_VERSION"] = "6"
+        # Pretty much all of the above but for Qt6
         os.environ["QT_QPA_PLATFORMTHEME"] = "kde"
 
         self.app = QApplication(["ubuntu-release-upgrader"])
@@ -601,28 +557,23 @@ class DistUpgradeViewKDE(DistUpgradeView):
         # Try to load default Qt translations so we don't have to worry about
         # QStandardButton translations.
         translator = QTranslator(self.app)
-        if type(PYQT_VERSION) == int:
-            translator.load(QLocale.system(), 'qt', '_', '/usr/share/qt5/translations')
-        else:
-            translator.load(QLocale.system(), 'qt', '_', '/usr/share/qt4/translations')
+        translator.load(QLocale.system(), 'qt', '_', '/usr/share/qt6/translations')
         self.app.installTranslator(translator)
 
         QUrlOpener().setupUrlHandles()
+        self.app.aboutToQuit.connect(QUrlOpener().teardownUrlHandles)
 
         messageIcon = _icon("system-software-update",
                             fallbacks=["/usr/share/icons/oxygen/48x48/apps/system-software-update.png",
                                        "/usr/share/icons/hicolor/48x48/apps/adept_manager.png"])
         self.app.setWindowIcon(messageIcon)
-
         self.window_main = UpgraderMainWindow()
-        self.window_main.setParent(self)
         self.window_main.show()
 
         self.prev_step = None # keep a record of the latest step
 
         self._opCacheProgress = KDEOpProgress(self.window_main.progressbar_cache, self.window_main.progress_text)
         self._acquireProgress = KDEAcquireProgressAdapter(self)
-        self._cdromProgress = KDECdromProgressAdapter(self)
 
         self._installProgress = KDEInstallProgressAdapter(self)
 
@@ -639,9 +590,13 @@ class DistUpgradeViewKDE(DistUpgradeView):
         name = _OSRelease().result["PRETTY_NAME"]
         if not name or name == "Ubuntu":
             name = "Kubuntu"
+
+        to_dist = self.config.get("Sources", "To")
+        to_version = distro_info.UbuntuDistroInfo().version(to_dist)
+
         title_string = self.window_main.label_title.text()
         title_string = title_string.replace("Ubuntu", name)
-        title_string = title_string.replace("%s", "21.10")
+        title_string = title_string.replace("%s", to_version)
         self.window_main.label_title.setText(title_string)
 
         # setup terminal text in hidden by default spot
@@ -652,47 +607,16 @@ class DistUpgradeViewKDE(DistUpgradeView):
         self.konsole_frame_layout.addWidget(self.terminal_text)
         self.terminal_text.show()
 
-        self.inhibitScreenlock()
-        atexit.register(self.uninhibitScreenlock)
-
         # for some reason we need to start the main loop to get everything displayed
         # this app mostly works with processEvents but run main loop briefly to keep it happily displaying all widgets
         QTimer.singleShot(10, self.exitMainLoopMidFlight)
-        self.app.exec_()
+        self.app.exec()
 
     def exitMainLoopMidFlight(self):
         # This is run shortly after startup. Do not add actual exit logic here!
         print("exitMainLoopMidFlight")
         self.app.exit()
 
-    def inhibitScreenlock(self):
-        if not QDBusConnection.sessionBus().isConnected():
-            sys.stderr.write("Cannot connect to the D-Bus session bus.\n"
-                    "To start it, run:\n"
-                    "\teval `dbus-launch --auto-syntax`\n");
-            return
-
-        iface = QDBusInterface('org.kde.screensaver', '/ScreenSaver', '',
-                QDBusConnection.sessionBus())
-
-        if iface.isValid():
-            msg = iface.call('Inhibit', 'DisUpgradeViewKDE', 'Upgrading base OS')
-            reply = QDBusReply(msg)
-            self.screenLockCookie = reply.value()
-
-    def uninhibitScreenlock(self):
-        if not QDBusConnection.sessionBus().isConnected():
-            sys.stderr.write("Cannot connect to the D-Bus session bus.\n"
-                    "To start it, run:\n"
-                    "\teval `dbus-launch --auto-syntax`\n");
-            return
-
-        iface = QDBusInterface('org.kde.screensaver', '/ScreenSaver', '',
-                QDBusConnection.sessionBus())
-
-        if iface.isValid():
-            iface.call('UnInhibit', self.screenLockCookie)
-
     def translate_widget_children(self, parentWidget=None):
         if parentWidget == None:
             parentWidget = self.window_main
@@ -744,7 +668,7 @@ class DistUpgradeViewKDE(DistUpgradeView):
             dialog.crash_detail.setText(tbtext)
             # Make sure we have a suitable size depending on whether or not the view is shown
             dialog.adjustSize()
-            dialog.exec_()
+            dialog.exec()
         sys.exit(1)
 
     def showTerminal(self):
@@ -766,9 +690,6 @@ class DistUpgradeViewKDE(DistUpgradeView):
     def getOpCacheProgress(self):
         return self._opCacheProgress
 
-    def getCdromProgress(self):
-        return self._cdromProgress
-
     def update_status(self, msg):
         self.window_main.label_status.setText(msg)
 
@@ -783,8 +704,7 @@ class DistUpgradeViewKDE(DistUpgradeView):
         if step:
             image = getattr(self.window_main,"image_step%i" % step.value)
             cancelIcon = _icon("dialog-cancel",
-                               fallbacks=["/usr/share/icons/oxygen/16x16/actions/dialog-cancel.png",
-                                          "/usr/lib/kde4/share/icons/oxygen/16x16/actions/dialog-cancel.png",
+                               fallbacks=["/usr/share/icons/oxygen/base/16x16/actions/dialog-cancel.png",
                                           "/usr/share/icons/crystalsvg/16x16/actions/cancel.png"])
             image.setPixmap(cancelIcon.pixmap(16, 16))
             image.show()
@@ -792,12 +712,10 @@ class DistUpgradeViewKDE(DistUpgradeView):
     def setStep(self, step):
         super(DistUpgradeViewKDE , self).setStep(step)
         okIcon = _icon("dialog-ok",
-                       fallbacks=["/usr/share/icons/oxygen/16x16/actions/dialog-ok.png",
-                                  "/usr/lib/kde4/share/icons/oxygen/16x16/actions/dialog-ok.png",
+                       fallbacks=["/usr/share/icons/oxygen/base/16x16/actions/dialog-ok.png",
                                   "/usr/share/icons/crystalsvg/16x16/actions/ok.png"])
         arrowIcon = _icon("arrow-right",
-                          fallbacks=["/usr/share/icons/oxygen/16x16/actions/arrow-right.png",
-                                     "/usr/lib/kde4/share/icons/oxygen/16x16/actions/arrow-right.png",
+                          fallbacks=["/usr/share/icons/oxygen/base/16x16/actions/arrow-right.png",
                                      "/usr/share/icons/crystalsvg/16x16/actions/1rightarrow.png"])
 
         if self.prev_step:
@@ -829,13 +747,12 @@ class DistUpgradeViewKDE(DistUpgradeView):
         dialogue.setWindowTitle(_("Information"))
 
         messageIcon = _icon("dialog-information",
-                            fallbacks=["/usr/share/icons/oxygen/48x48/status/dialog-information.png",
-                                       "/usr/lib/kde4/share/icons/oxygen/48x48/status/dialog-information.png",
+                            fallbacks=["/usr/share/icons/oxygen/base/48x48/status/dialog-information.png",
                                        "/usr/share/icons/crystalsvg/32x32/actions/messagebox_info.png"])
         dialogue.image.setPixmap(messageIcon.pixmap(48, 48))
         # Make sure we have a suitable size depending on whether or not the view is shown
         dialogue.adjustSize()
-        dialogue.exec_()
+        dialogue.exec()
 
     def error(self, summary, msg, extended_msg=None):
         msg="<big><b>%s</b></big><br />%s" % (summary, msg)
@@ -851,22 +768,21 @@ class DistUpgradeViewKDE(DistUpgradeView):
             dialogue.textview_error.hide()
 
         messageIcon = _icon("dialog-error",
-                            fallbacks=["/usr/share/icons/oxygen/48x48/status/dialog-error.png",
-                                       "/usr/lib/kde4/share/icons/oxygen/48x48/status/dialog-error.png",
+                            fallbacks=["/usr/share/icons/oxygen/base/48x48/status/dialog-error.png",
                                        "/usr/share/icons/crystalsvg/32x32/actions/messagebox_critical.png"])
         dialogue.image.setPixmap(messageIcon.pixmap(48, 48))
         # Make sure we have a suitable size depending on whether or not the view is shown
         dialogue.adjustSize()
-        dialogue.exec_()
+        dialogue.exec()
 
         return False
 
-    def confirmChanges(self, summary, changes, demotions, downloadSize,
+    def confirmChanges(self, summary, changes, downloadSize,
                        actions=None, removal_bold=True):
         """show the changes dialogue"""
-        # FIXME: add a whitelist here for packages that we expect to be
+        # FIXME: add an allow list here for packages that we expect to be
         # removed (how to calc this automatically?)
-        DistUpgradeView.confirmChanges(self, summary, changes, demotions,
+        DistUpgradeView.confirmChanges(self, summary, changes,
                                        downloadSize)
         self.changesDialogue = QDialog(self.window_main)
         loadUi("dialog_changes.ui", self.changesDialogue)
@@ -874,21 +790,20 @@ class DistUpgradeViewKDE(DistUpgradeView):
         self.changesDialogue.treeview_details.hide()
         self.changesDialogue.buttonBox.helpRequested.connect(self.showChangesDialogueDetails)
         self.translate_widget_children(self.changesDialogue)
-        self.changesDialogue.buttonBox.button(QDialogButtonBox.Ok).setText(_("&Start Upgrade"))
-        self.changesDialogue.buttonBox.button(QDialogButtonBox.Help).setIcon(QIcon())
-        self.changesDialogue.buttonBox.button(QDialogButtonBox.Help).setText(_("Details") + " >>>")
+        self.changesDialogue.buttonBox.button(QDialogButtonBox.StandardButton.Ok).setText(_("&Start Upgrade"))
+        self.changesDialogue.buttonBox.button(QDialogButtonBox.StandardButton.Help).setIcon(QIcon())
+        self.changesDialogue.buttonBox.button(QDialogButtonBox.StandardButton.Help).setText(_("Details") + " >>>")
 
         messageIcon = _icon("dialog-warning",
-                            fallbacks=["/usr/share/icons/oxygen/48x48/status/dialog-warning.png",
-                                       "/usr/lib/kde4/share/icons/oxygen/48x48/status/dialog-warning.png",
+                            fallbacks=["/usr/share/icons/oxygen/base/48x48/status/dialog-warning.png",
                                        "/usr/share/icons/crystalsvg/32x32/actions/messagebox_warning.png"])
         self.changesDialogue.question_pixmap.setPixmap(messageIcon.pixmap(48, 48))
 
         if actions != None:
             cancel = actions[0].replace("_", "")
-            self.changesDialogue.buttonBox.button(QDialogButtonBox.Cancel).setText(cancel)
+            self.changesDialogue.buttonBox.button(QDialogButtonBox.StandardButton.Cancel).setText(cancel)
             confirm = actions[1].replace("_", "")
-            self.changesDialogue.buttonBox.button(QDialogButtonBox.Ok).setText(confirm)
+            self.changesDialogue.buttonBox.button(QDialogButtonBox.StandardButton.Ok).setText(confirm)
 
         summaryText = "<big><b>%s</b></big>" % summary
         self.changesDialogue.label_summary.setText(summaryText)
@@ -897,8 +812,6 @@ class DistUpgradeViewKDE(DistUpgradeView):
         self.changesDialogue.treeview_details.clear()
         self.changesDialogue.treeview_details.setHeaderLabels(["Packages"])
         self.changesDialogue.treeview_details.header().hide()
-        for demoted in self.demotions:
-            self.changesDialogue.treeview_details.insertTopLevelItem(0, QTreeWidgetItem(self.changesDialogue.treeview_details, [_("No longer supported %s") % demoted.name]) )
         for rm in self.toRemove:
             self.changesDialogue.treeview_details.insertTopLevelItem(0, QTreeWidgetItem(self.changesDialogue.treeview_details, [_("Remove %s") % rm.name]) )
         for rm in self.toRemoveAuto:
@@ -912,30 +825,30 @@ class DistUpgradeViewKDE(DistUpgradeView):
         self.changesDialogue.adjustSize()
 
         #FIXME resize label, stop it being shrinkable
-        res = self.changesDialogue.exec_()
-        if res == QDialog.Accepted:
+        res = self.changesDialogue.exec()
+        if res == QDialog.DialogCode.Accepted:
             return True
         return False
 
     def showChangesDialogueDetails(self):
         if self.changesDialogue.treeview_details.isVisible():
             self.changesDialogue.treeview_details.hide()
-            self.changesDialogue.buttonBox.button(QDialogButtonBox.Help).setText(_("Details") + " >>>")
+            self.changesDialogue.buttonBox.button(QDialogButtonBox.StandardButton.Help).setText(_("Details") + " >>>")
         else:
             self.changesDialogue.treeview_details.show()
-            self.changesDialogue.buttonBox.button(QDialogButtonBox.Help).setText("<<< " + _("Details"))
+            self.changesDialogue.buttonBox.button(QDialogButtonBox.StandardButton.Help).setText("<<< " + _("Details"))
         self.changesDialogue.adjustSize()
 
     def askYesNoQuestion(self, summary, msg, default='No'):
-        answer = QMessageBox.question(self.window_main, summary, "<font>" + msg, QMessageBox.Yes|QMessageBox.No, QMessageBox.No)
-        if answer == QMessageBox.Yes:
+        answer = QMessageBox.question(self.window_main, summary, "<font>" + msg, QMessageBox.StandardButton.Yes|QMessageBox.StandardButton.No, QMessageBox.StandardButton.No)
+        if answer == QMessageBox.StandardButton.Yes:
             return True
         return False
 
     def askCancelContinueQuestion(self, summary, msg, default='Cancel'):
-        messageBox = QMessageBox(QMessageBox.Warning, summary, msg, QMessageBox.NoButton, self.window_main)
-        continueButton = messageBox.addButton(QMessageBox.Apply)
-        cancelButton = messageBox.addButton(QMessageBox.Cancel)
+        messageBox = QMessageBox(QMessageBox.Warning, summary, msg, QMessageBox.StandardButton.NoButton, self.window_main)
+        continueButton = messageBox.addButton(QMessageBox.StandardButton.Apply)
+        cancelButton = messageBox.addButton(QMessageBox.StandardButton.Cancel)
         continueButton.setText(_("Continue"))
 
         if default == 'Cancel':
@@ -947,19 +860,19 @@ class DistUpgradeViewKDE(DistUpgradeView):
             flags = messageBox.windowFlags()
             messageBox.setWindowFlags(flags | Qt.FramelessWindowHint)
 
-        answer = messageBox.exec_()
-        if answer == QMessageBox.Apply:
+        answer = messageBox.exec()
+        if answer == QMessageBox.StandardButton.Apply:
             return True
         return False
 
     def confirmRestart(self):
-        messageBox = QMessageBox(QMessageBox.Question, _("Restart required"), _("<b><big>Restart the system to complete the upgrade</big></b>"), QMessageBox.NoButton, self.window_main)
-        yesButton = messageBox.addButton(QMessageBox.Yes)
-        noButton = messageBox.addButton(QMessageBox.No)
+        messageBox = QMessageBox(QMessageBox.Icon.Question, _("Restart required"), _("<b><big>Restart the system to complete the upgrade</big></b>"), QMessageBox.StandardButton.NoButton, self.window_main)
+        yesButton = messageBox.addButton(QMessageBox.StandardButton.Yes)
+        noButton = messageBox.addButton(QMessageBox.StandardButton.No)
         yesButton.setText(_("_Restart Now").replace("_", "&"))
         noButton.setText(gettext.dgettext("kdelibs", "&Close"))
-        answer = messageBox.exec_()
-        if answer == QMessageBox.Yes:
+        answer = messageBox.exec()
+        if answer == QMessageBox.StandardButton.Yes:
             return True
         return False
 
@@ -978,46 +891,7 @@ class DistUpgradeViewKDE(DistUpgradeView):
 
 The system could be in an unusable state if you cancel the upgrade. You are strongly advised to resume the upgrade.""")
         text = text.replace("\n", "<br />")
-        cancel = QMessageBox.warning(self.window_main, _("Cancel Upgrade?"), text, QMessageBox.Yes, QMessageBox.No)
-        if cancel == QMessageBox.Yes:
+        cancel = QMessageBox.warning(self.window_main, _("Cancel Upgrade?"), text, QMessageBox.StandardButton.Yes, QMessageBox.StandardButton.No)
+        if cancel == QMessageBox.StandardButton.Yes:
             return True
         return False
-
-
-if __name__ == "__main__":
-
-  view = DistUpgradeViewKDE()
-  view.askYesNoQuestion("input box test","bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar bar ")
-
-  if sys.argv[1] == "--test-term":
-      pid = view.terminal_text.fork()
-      if pid == 0:
-          subprocess.call(["bash"])
-          sys.exit()
-      while True:
-          view.terminal_text.update_interface()
-          QApplication.processEvents()
-          time.sleep(0.01)
-
-  if sys.argv[1] == "--show-in-terminal":
-      with open(sys.argv[2]) as f:
-          chars = f.read()
-      for c in chars:
-          view.terminal_text.insertWithTermCodes( c )
-          #print(c, ord(c))
-          QApplication.processEvents()
-          time.sleep(0.05)
-      while True:
-          QApplication.processEvents()
-
-  cache = apt.Cache()
-  for pkg in sys.argv[1:]:
-    if cache[pkg].is_installed and not cache[pkg].is_upgradable:
-      cache[pkg].mark_delete(purge=True)
-    else:
-      cache[pkg].mark_install()
-  cache.commit(view._acquireProgress,view._installProgress)
-
-  # keep the window open
-  while True:
-      QApplication.processEvents()
