@@ -546,26 +546,14 @@ max_framebuffers=2
 
 class TestSnapQuirks(unittest.TestCase):
 
-    def test_get_from_and_to_version(self):
-        # Prepare the state for testing
-        controller = mock.Mock()
-        controller.fromDist = 'disco'
-        controller.toDist = 'eoan'
-        config = mock.Mock()
-        q = DistUpgradeQuirks(controller, config)
-        # Call method under test
-        q._get_from_and_to_version()
-        self.assertEqual(q._from_version, '19.04')
-        self.assertEqual(q._to_version, '19.10')
-
     @mock.patch("subprocess.Popen", MockPopenSnap)
     def test_prepare_snap_replacement_data(self):
         # Prepare the state for testing
         controller = mock.Mock()
         config = mock.Mock()
+        controller.fromVersion = '24.04'
+        controller.toVersion = '24.10'
         q = DistUpgradeQuirks(controller, config)
-        q._from_version = "24.04"
-        q._to_version = "24.10"
         # Call method under test
 
         controller.cache = {
@@ -643,8 +631,6 @@ class TestSnapQuirks(unittest.TestCase):
         controller = mock.Mock()
         config = mock.Mock()
         q = DistUpgradeQuirks(controller, config)
-        q._from_version = "19.04"
-        q._to_version = "19.10"
         controller.cache = {
             'ubuntu-desktop':
                 make_mock_pkg(
@@ -667,13 +653,81 @@ class TestSnapQuirks(unittest.TestCase):
                              data[1],
                              'Expected {1} for input {0}'.format(*data))
 
-    @mock.patch("DistUpgrade.DistUpgradeQuirks.get_arch")
-    @mock.patch("urllib.request.urlopen")
-    def test_calculate_snap_size_requirements(self, urlopen, arch):
-        # Prepare the state for testing
-        arch.return_value = 'amd64'
+    def test_parse_deb2snap_json(self):
         controller = mock.Mock()
         config = mock.Mock()
+
+        q = DistUpgradeQuirks(controller, config)
+        q.controller.toVersion = '25.04'
+        q._is_deb2snap_metapkg_installed = mock.Mock()
+        q._is_deb2snap_metapkg_installed.return_value = True
+
+        for from_version in ('22.04', '22.10'):
+            q.controller.fromVersion = from_version
+
+            m = mock.mock_open(read_data=(
+                '{'
+                '  "seeded": {'
+                '    "test-snap-1": {'
+                '      "metapkg": "ubuntu-desktop-minimal",'
+                '      "from_channel": "latest/edge",'
+                '      "to_channel": "latest/stable"'
+                '    },'
+                '    "test-snap-2": {'
+                '      "deb": "test-deb-2",'
+                '      "metapkg": "ubuntu-desktop-minimal"'
+                '    },'
+                '    "test-snap-3": {'
+                '      "metapkg": "ubuntu-desktop-minimal",'
+                '      "force_switch": true,'
+                '      "from_channel": "1/stable/ubuntu-{FROM_VERSION}",'
+                '      "to_channel": "2/stable/ubuntu-{TO_VERSION}"'
+                '    }'
+                '  },'
+                '  "unseeded": {'
+                '  }'
+                '}'
+            ))
+
+            with mock.patch('DistUpgrade.DistUpgradeQuirks.open', m):
+                seeded, unseeded = q._parse_deb2snap_json()
+
+                self.assertEqual(unseeded, {})
+
+                self.assertEqual(
+                    seeded['test-snap-1'],
+                    (
+                        None,
+                        'latest/edge',
+                        'latest/stable',
+                        False
+                    )
+                )
+                self.assertEqual(
+                    seeded['test-snap-2'],
+                    (
+                        'test-deb-2',
+                        f'stable/ubuntu-{q.controller.fromVersion}',
+                        f'stable/ubuntu-{q.controller.toVersion}',
+                        False
+                    )
+                )
+                self.assertEqual(
+                    seeded['test-snap-3'],
+                    (
+                        None,
+                        f'1/stable/ubuntu-{q.controller.fromVersion}',
+                        f'2/stable/ubuntu-{q.controller.toVersion}',
+                        True
+                    )
+                )
+
+    @mock.patch("urllib.request.urlopen")
+    def test_calculate_snap_size_requirements(self, urlopen):
+        # Prepare the state for testing
+        controller = mock.Mock()
+        controller.arch = 'amd64'
+        config = mock.Mock()
         q = DistUpgradeQuirks(controller, config)
         # We mock out _prepare_snap_replacement_data(), as this is tested
         # separately.
@@ -689,7 +743,6 @@ class TestSnapQuirks(unittest.TestCase):
             'gnome-system-monitor': {'command': 'refresh',
                                      'channel': 'stable/ubuntu-19.10'}
         }
-        q._to_version = "19.10"
         # Mock out urlopen in such a way that we get a mocked response based
         # on the parameters given but also allow us to check call arguments
         # etc.
@@ -737,7 +790,6 @@ class TestSnapQuirks(unittest.TestCase):
                            'snap-id': '1234',
                            'channel': 'stable/ubuntu-19.10'}
         }
-        q._to_version = "19.10"
         q._replaceDebsAndSnaps()
         # Make sure all snaps have been handled
         self.assertEqual(run_mock.call_count, 8)
